@@ -18,7 +18,8 @@
 
 #include <config.h>
 
-#include <gdk/gdkcolor.h>
+#include <stdlib.h>
+#include <gdk/gdk.h>
 #ifdef HAVE_SPECTRE
 #include <libspectre/spectre.h>
 #endif
@@ -244,19 +245,16 @@ dvi_cairo_free_image (void *ptr)
 static void
 dvi_cairo_put_pixel (void *image, int x, int y, Ulong color)
 {
-	cairo_t         *cr;
 	cairo_surface_t *surface;
 	gint             rowstride;
-	guchar          *p;
+	guint32         *p;
 
 	surface = (cairo_surface_t *) image;
 
 	rowstride = cairo_image_surface_get_stride (surface);
-	p = cairo_image_surface_get_data (surface) + y * rowstride + x * 4;
+	p = (guint32*) (cairo_image_surface_get_data (surface) + y * rowstride + x * 4);
 
-	p[2] = (color >> 16) & 0xff;
-	p[1] = (color >> 8) & 0xff;
-	p[0] = (color >> 0) & 0xff;
+	*p = color;
 }
 
 static void
@@ -319,7 +317,7 @@ mdvi_cairo_device_render (DviContext* dvi)
 	gint             page_width;
 	gint             page_height;
 	cairo_surface_t *surface;
-	gchar           *pixels;
+	guchar          *pixels;
 	gint             rowstride;
 	static const cairo_user_data_key_t key;
 
@@ -332,7 +330,7 @@ mdvi_cairo_device_render (DviContext* dvi)
 	page_height = dvi->dvi_page_h * dvi->params.vconv + 2 * cairo_device->ymargin;
 
 	rowstride = page_width * 4;
-	pixels = (gchar *) g_malloc (page_height * rowstride);
+	pixels = (guchar *) g_malloc (page_height * rowstride);
 	memset (pixels, 0xff, page_height * rowstride);
 
 	surface = cairo_image_surface_create_for_data (pixels,
