@@ -27,15 +27,13 @@
 #include <gtk/gtk.h>
 
 #include "ev-link.h"
-#include "ev-page-cache.h"
 
 G_BEGIN_DECLS
 
 typedef enum {
 	EV_WINDOW_MODE_NORMAL,
 	EV_WINDOW_MODE_FULLSCREEN,
-	EV_WINDOW_MODE_PRESENTATION,
-	EV_WINDOW_MODE_PREVIEW
+	EV_WINDOW_MODE_PRESENTATION
 } EvWindowRunMode;
 
 typedef struct {
@@ -70,27 +68,23 @@ struct _EvWindowClass {
 	GtkWindowClass		base_class;
 };
 
-GType		ev_window_get_type	  (void);
-GtkWidget      *ev_window_new             (void);
-const char     *ev_window_get_uri         (EvWindow       *ev_window);
-void		ev_window_open_uri	  (EvWindow       *ev_window,
-					   const char     *uri,
-					   EvLinkDest     *dest,
-					   EvWindowRunMode mode,
-					   const gchar    *search_string,
-					   gboolean        unlink_temp_file,
-					   const gchar    *print_settings);
-gboolean	ev_window_is_empty	  (const EvWindow *ev_window);
-void		ev_window_print_range     (EvWindow       *ev_window,
-					   int             first_page,
-					   int		   last_page);
-
-void		ev_window_go_last_page	  (EvWindow       *ev_window);
-void		ev_window_go_first_page	  (EvWindow       *ev_window);
-void		ev_window_go_next_page	  (EvWindow       *ev_window);
-void		ev_window_go_previous_page(EvWindow       *ev_window);
-void		ev_window_start_presentation
-					  (EvWindow       *ev_window);
+GType		ev_window_get_type	(void) G_GNUC_CONST;
+GtkWidget      *ev_window_new           (void);
+const char     *ev_window_get_uri       (EvWindow       *ev_window);
+void		ev_window_open_uri	(EvWindow       *ev_window,
+					 const char     *uri,
+					 EvLinkDest     *dest,
+					 EvWindowRunMode mode,
+					 const gchar    *search_string);
+void		ev_window_open_document (EvWindow       *ev_window,
+					 EvDocument     *document,
+					 EvLinkDest     *dest,
+					 EvWindowRunMode mode,
+					 const gchar    *search_string);
+gboolean	ev_window_is_empty	(const EvWindow *ev_window);
+void		ev_window_print_range   (EvWindow       *ev_window,
+					 int             first_page,
+					 int		 last_page);
 
 G_END_DECLS
 
